[Bf-blender-cvs] [b2f04fce2d2] master: Fix T75062: Frame Flashes During 3D Viewport Animation Playback

Jeroen Bakker noreply at git.blender.org
Thu Mar 26 08:23:21 CET 2020


Commit: b2f04fce2d21c631c5a0d4e5015c8b7b0c0c8d0d
Author: Jeroen Bakker
Date:   Thu Mar 26 08:18:07 2020 +0100
Branches: master
https://developer.blender.org/rBb2f04fce2d21c631c5a0d4e5015c8b7b0c0c8d0d

Fix T75062: Frame Flashes During 3D Viewport Animation Playback

This issue became visible after fixing other TAA issues recently.
The sample count of the first frame wasn't reset resulting that the
incorrect resolve took place. This issue was already there beforehand,
it is just much clearer during the recent changes.

Now the `taa_sample will be reset when performing an animation playback
in the 3d viewport.

===================================================================

M	source/blender/draw/engines/workbench/workbench_effect_antialiasing.c

===================================================================

diff --git a/source/blender/draw/engines/workbench/workbench_effect_antialiasing.c b/source/blender/draw/engines/workbench/workbench_effect_antialiasing.c
index cbc146bb7fe..a0db09e9273 100644
--- a/source/blender/draw/engines/workbench/workbench_effect_antialiasing.c
+++ b/source/blender/draw/engines/workbench/workbench_effect_antialiasing.c
@@ -168,9 +168,9 @@ void workbench_antialiasing_engine_init(WORKBENCH_Data *vedata)
 
   wpd->view = NULL;
 
   /* reset complete drawing when navigating. */
   if (wpd->taa_sample != 0) {
-    if (wpd->is_navigating) {
+    if (wpd->is_navigating || wpd->is_playback) {
       wpd->taa_sample = 0;
     }
   }
@@ -424,7 +424,6 @@ void workbench_antialiasing_draw_pass(WORKBENCH_Data *vedata)
 
   const bool last_sample = wpd->taa_sample + 1 == wpd->taa_sample_len;
   const bool taa_finished = wpd->taa_sample >= wpd->taa_sample_len;
-
   if (wpd->taa_sample == 0) {
     /* In playback mode, we are sure the next redraw will not use the same viewmatrix.
      * In this case no need to save the depth buffer. */
@@ -168,9 +168,9 @@ void workbench_antialiasing_engine_init(WORKBENCH_Data *vedata)
   wpd->view = NULL;
 
-  /* reset complete drawing when navigating. */
+  /* reset complete drawing when navigating or during viewport playback. */
   if (wpd->taa_sample != 0) {



More information about the Bf-blender-cvs mailing list